% Script to plot accelerations from Abaqus
% with those from measurements
clear all
close all
clc

% Give simulation folder
folder = 'z1_C_v33.2_mesh5\';

% Loading data from wind velocity simulation
Acc2_abaqus = load([num2str(folder) 'Accel_3_Node_272.txt']);
Acc5_abaqus = load([num2str(folder) 'Accel_3_Node_661.txt']);
Acc8_abaqus = load([num2str(folder) 'Accel_3_Node_872.txt']);
Acc51_abaqus = load([num2str(folder) 'Accel_3_Node_422.txt']);
t2_abaqus = Acc2_abaqus(:,1)-1;
t5_abaqus = Acc5_abaqus(:,1)-1;
t8_abaqus = Acc8_abaqus(:,1)-1;
t51_abaqus = Acc51_abaqus(:,1)-1;
Acc2_abaqus = Acc2_abaqus(:,2);
Acc5_abaqus = Acc5_abaqus(:,2);
Acc8_abaqus = Acc8_abaqus(:,2);
Acc51_abaqus = Acc51_abaqus(:,2);

% data incl the storm PER
dataPlace = 'C:\Users\Jorgen\Documents\Skole\Fall 11\Prosjekt\Matlab\Tidsserier\dec2006_sep2007\';

TabelsAll = dir(dataPlace);

[dataFile] = TabelsAll(60).name;
[a1,a2] = catman_read([dataPlace dataFile]);

A = a2(71).data;% Vind H
Acc2_measured = a2(2).data./1000;% ACCQ-YW, Node 152 = 1/4 point bridge
Acc5_measured = a2(5).data./1000;% ACCM-YW, Node 511 = midpoint bridge
Acc8_measured = a2(8).data./1000;% ACCS14-Y, Node 872 = 1/4 point arch
Acc51_measured = a2(51).data./1000;% ACCN26-Y, Node 422 = midpoint arch
Acc2_measured = detrend(Acc2_measured,'constant');
Acc5_measured = detrend(Acc5_measured,'constant');
Acc8_measured = detrend(Acc8_measured,'constant');
Acc51_measured = detrend(Acc51_measured,'constant');
t_measured = 0:0.02:(length(A)-1)*0.02;

% Calculating the standard deviation
std_Acc2_measured = std(Acc2_measured);
std_Acc5_measured = std(Acc5_measured);
std_Acc8_measured = std(Acc8_measured);
std_Acc51_measured = std(Acc51_measured);
std_Acc2_abaqus = std(Acc2_abaqus);
std_Acc5_abaqus = std(Acc5_abaqus);
std_Acc8_abaqus = std(Acc8_abaqus);
std_Acc51_abaqus = std(Acc51_abaqus);

disp(['Standard deviation measured from Node 152 = 1/4 point bridge west side: ',num2str(std_Acc2_measured)])
disp(['Standard deviation from Abaqus Node 272 = east side: ',num2str(std_Acc2_abaqus)])
disp(['Standard deviation measured from Node 511 = midpoint bridge west side: ',num2str(std_Acc5_measured)])
disp(['Standard deviation from Abaqus Node 661 = east side: ',num2str(std_Acc5_abaqus)])
disp(['Standard deviation measured from Node 872 = 1/4 point arch: ',num2str(std_Acc8_measured)])
disp(['Standard deviation from Abaqus Node 872: ',num2str(std_Acc8_abaqus)])
disp(['Standard deviation measured from Node 422 = midpoint arch: ',num2str(std_Acc51_measured)])
disp(['Standard deviation from Abaqus Node 422: ',num2str(std_Acc51_abaqus)])

% Plotting result
% Node 272
figure('Name','Node 152 & 272 = 1/4 point bridge')
subplot(2,1,1)
    plot(t_measured,Acc2_measured)
    grid
    title('From measurements')
    %axis([0 600 -0.5 0.5])
subplot(2,1,2)
    plot(t2_abaqus,Acc2_abaqus)
    grid
    title('Node 272 from Abaqus')
    %axis([0 600 -0.05 0.05])

% Node 661
figure('Name','Node 511 & 661 = midpoint bridge')
subplot(2,1,1)
    plot(t_measured,Acc5_measured)
    grid
    title('From measurements')
    %axis([0 600 -0.5 0.5])
subplot(2,1,2)
    plot(t5_abaqus,Acc5_abaqus)
    grid
    title('Node 661 from Abaqus')
    %axis([0 600 -0.05 0.05])
    
% Node 872
figure('Name','Node 872 = 1/4 point arch')
subplot(2,1,1)
    plot(t_measured,Acc8_measured)
    grid
    title('From measurements')
    %axis([0 600 -0.5 0.5])
subplot(2,1,2)
    plot(t8_abaqus,Acc8_abaqus)
    grid
    title('From Abaqus')
    %axis([0 600 -0.05 0.05])

% Node 422
figure('Name','Node 422 = midpoint arch')
subplot(2,1,1)
    plot(t_measured,Acc51_measured)
    grid
    title('From measurements')
    %axis([0 600 -0.5 0.5])
subplot(2,1,2)
    plot(t51_abaqus,Acc51_abaqus)
    grid
    title('From Abaqus')
    %axis([0 600 -0.05 0.05])