clear all
close all
clc

%%
simulation_name = 'Full in 2 points';
folder = 'C:\Users\Jorgen\Dropbox\Masteroppgave\Matlab\Accel from Abaqus\full_in_2points\';
name = ['z1_C_v33.2_mesh5';'z2_C_v33.2_mesh5';'z3_C_v33.2_mesh5';'z4_C_v33.2_mesh5';...
    'z1_D_v33.2_mesh5';'z1_B_v33.2_mesh5';'z1_A_v33.2_mesh5'];
    
% Loading data from wind velocity simulation
number_sim = size(name,1);
Acc_abaqus = zeros(number_sim,2404,4);
t_abaqus = zeros(number_sim,2404,4);

for i = 1:number_sim
    Acc3_abaqus = load([num2str(folder), num2str(name(i,:)), '\Accel_3_Node_152.txt']);
    Acc6_abaqus = load([num2str(folder) num2str(name(i,:)) '\Accel_3_Node_511.txt']);
    Acc8_abaqus = load([num2str(folder) num2str(name(i,:)) '\Accel_3_Node_872.txt']);
    Acc51_abaqus = load([num2str(folder) num2str(name(i,:)) '\Accel_3_Node_422.txt']);
    t3_abaqus = Acc3_abaqus(:,1)-1;
    t6_abaqus = Acc6_abaqus(:,1)-1;
    t8_abaqus = Acc8_abaqus(:,1)-1;
    t51_abaqus = Acc51_abaqus(:,1)-1;
    Acc3_abaqus = Acc3_abaqus(:,2);
    Acc6_abaqus = Acc6_abaqus(:,2);
    Acc8_abaqus = Acc8_abaqus(:,2);
    Acc51_abaqus = Acc51_abaqus(:,2);
    
    length_Acc = length(Acc3_abaqus);
    
    if length_Acc <= 2400
        Acc_abaqus(i,:,1) = Acc3_abaqus;
        Acc_abaqus(i,:,2) = Acc6_abaqus;
        Acc_abaqus(i,:,3) = Acc8_abaqus;
        Acc_abaqus(i,:,4) = Acc51_abaqus;

        t_abaqus(i,:,1) = t3_abaqus;
        t_abaqus(i,:,2) = t6_abaqus;
        t_abaqus(i,:,3) = t8_abaqus;
        t_abaqus(i,:,4) = t51_abaqus;
    elseif length_Acc >= 2400
        Acc_abaqus(i,:,1) = Acc3_abaqus(1:2404);
        Acc_abaqus(i,:,2) = Acc6_abaqus(1:2404);
        Acc_abaqus(i,:,3) = Acc8_abaqus(1:2404);
        Acc_abaqus(i,:,4) = Acc51_abaqus(1:2404);

        t_abaqus(i,:,1) = t3_abaqus(1:2404);
        t_abaqus(i,:,2) = t6_abaqus(1:2404);
        t_abaqus(i,:,3) = t8_abaqus(1:2404);
        t_abaqus(i,:,4) = t51_abaqus(1:2404);
    end
end

%% Plotting result
interval_no = 4;

% Giving colors to be useed in the plots
colors = 'bkrgcmy';

%% Changing simulation approach z 
name_no = [1,2,3,4];
%% Welch method
N=size(t_abaqus,2);                   % Number of elements in the vectors
Fs=4;                                 % Sampling frequency
nfft=1*N;                             % Number of elements used in the FFT (Zero padding or not%)

Hs=spectrum.welch('Hamming',N/10,50); % Defines the spectrum estimator, the windowing function, number of windows, percentage overlap
figure('Name','Plot of PSD using Welch method')

for i = 1:interval_no
    subplot(interval_no,1,i)
        h=psd(Hs,Acc_abaqus(name_no(i),:,1),'NFFT',nfft,'Fs',Fs);
        semilogy(h.Frequencies,h.Data,colors(1))
        title(['Simulation: " ', num2str(simulation_name), ', ', num2str(name(name_no(i),1:2)), ' ', num2str(name(name_no(i),4)), '" using Welch method'])
        xlabel('Frequency Hz [1/s]')
        ylabel('Spectral Density S_x')
        xlim([0.1 2])
        ylim([10^-10 1])
        set(gca,'XGrid','on')
        hold on
            for j = 2:4
                h=psd(Hs,Acc_abaqus(name_no(i),:,j),'NFFT',nfft,'Fs',Fs);
                semilogy(h.Frequencies,h.Data,colors(j))
            end
end

%% Burg method
Fs=4;                                % Sampling frequency  
order=50;

Hs=spectrum.burg(order);
figure('Name','Plot of PSD using Burg method')
for i = 1:interval_no
    subplot(interval_no,1,i)
        h=psd(Hs,Acc_abaqus(name_no(i),:,1),'Fs',Fs);
        semilogy(h.Frequencies,h.Data,colors(1))
        xlim([0.1 2])
        ylim([10^-10 1])
        xlabel('Frequency Hz [1/s]')
        ylabel('Spectral Density S_x')
        title(['From simulation: "', num2str(simulation_name), ', ', num2str(name(name_no(i),1:2)), ' ', num2str(name(name_no(i),4)), '" using Burg method'])
        set(gca,'XGrid','on')
        hold on
            for j = 2:4
                h=psd(Hs,Acc_abaqus(name_no(i),:,j),'Fs',Fs);
                semilogy(h.Frequencies,h.Data,colors(j))
            end
        hold off
end

%% Changing exposure category
name_no = [7,6,1,5];

%% Welch method
N=size(t_abaqus,2);                   % Number of elements in the vectors
Fs=4;                                 % Sampling frequency
nfft=1*N;                             % Number of elements used in the FFT (Zero padding or not%)

Hs=spectrum.welch('Hamming',N/10,50); % Defines the spectrum estimator, the windowing function, number of windows, percentage overlap
figure('Name','Plot of PSD using Welch method')

for i = 1:interval_no
    subplot(interval_no,1,i)
        h=psd(Hs,Acc_abaqus(name_no(i),:,1),'NFFT',nfft,'Fs',Fs);
        semilogy(h.Frequencies,h.Data,colors(1))
        title(['Simulation: " ', num2str(simulation_name), ', ', num2str(name(name_no(i),1:2)), ' ', num2str(name(name_no(i),4)), '" using Welch method'])
        xlabel('Frequency Hz [1/s]')
        ylabel('Spectral Density S_x')
        xlim([0.1 2])
        ylim([10^-10 1])
        set(gca,'XGrid','on')
        hold on
            for j = 2:4
                h=psd(Hs,Acc_abaqus(name_no(i),:,j),'NFFT',nfft,'Fs',Fs);
                semilogy(h.Frequencies,h.Data,colors(j))
            end
end

%% Burg method
Fs=4;                                % Sampling frequency  
order=50;

Hs=spectrum.burg(order);
figure('Name','Plot of PSD using Burg method')
for i = 1:interval_no
    subplot(interval_no,1,i)
        h=psd(Hs,Acc_abaqus(name_no(i),:,1),'Fs',Fs);
        semilogy(h.Frequencies,h.Data,colors(1))
        xlim([0.1 2])
        ylim([10^-10 1])
        xlabel('Frequency Hz [1/s]')
        ylabel('Spectral Density S_x')
        title(['From simulation: "', num2str(simulation_name), ', ', num2str(name(name_no(i),1:2)), ' ', num2str(name(name_no(i),4)), '" using Burg method'])
        set(gca,'XGrid','on')
        hold on
            for j = 2:4
                h=psd(Hs,Acc_abaqus(name_no(i),:,j),'Fs',Fs);
                semilogy(h.Frequencies,h.Data,colors(j))
            end
        hold off
end