% Script to generate input file to abaqus
clear all
close all
clc

% Giving name of .mat file
name = 'z1_C_v33.2_mesh5';

% Loading data from wind velocity simulation
load([num2str(name) '.mat'])

% Loading nodes from txt file
% Nodes must be sorted with nodes in rising order on the arch
% then the superstructure nodes, with the node-pairs following each other
nodes = load('100nodes_x2.txt');

% Loading length between nodes from txt file
length_nodes = load('100lengths_x2.txt');

% Giving nodes placement
nodes_arch1 = 12;
nodes_arch2 = 14;
nodes_arch3 = 14;
nodes_arch4 = 12;
nodes_arch5 = 7;
nodes_arch2_sum = nodes_arch1+nodes_arch2;
nodes_arch3_sum = nodes_arch2_sum+nodes_arch3;
nodes_arch4_sum = nodes_arch3_sum+nodes_arch4;
nodes_arch5_sum = nodes_arch4_sum+nodes_arch5;

% Giving parameters
Cd_bue = 0.8;
Cd_bru = 0.15;
rho = 1.225;

% Calculating the static drag force
qq_stat = zeros(length(nodes),1);
mean_speed_temp = zeros(length(nodes),1);
mean_speed_temp(1:nodes_arch5_sum) = mean_speed(1:nodes_arch5_sum);
mean_speed_temp(nodes_arch5_sum+1:2:end) = mean_speed(nodes_arch5_sum+1:end);
mean_speed_temp(nodes_arch5_sum+2:2:end) = mean_speed(nodes_arch5_sum+1:end);
mean_speed = mean_speed_temp;
for i = 1:length(nodes)
    if i <= nodes_arch1
        qq_stat(i) = 0.5*rho*Cd_bue*4.2*(mean_speed(i)^2)*length_nodes(i);
    elseif i <= nodes_arch2_sum
        qq_stat(i) = 0.5*rho*Cd_bue*3.4*(mean_speed(i)^2)*length_nodes(i);
    elseif i <= nodes_arch3_sum
        qq_stat(i) = 0.5*rho*Cd_bue*3.167*(mean_speed(i)^2)*length_nodes(i);
    elseif i <= nodes_arch4_sum
        qq_stat(i) = 0.5*rho*Cd_bue*2.934*(mean_speed(i)^2)*length_nodes(i);
    elseif i <= nodes_arch5_sum
        qq_stat(i) = 0.5*rho*Cd_bue*2.7*(mean_speed(i)^2)*length_nodes(i);
    else
        qq_stat(i) = 0.5*rho*Cd_bru*27.6*(mean_speed(i)^2)*length_nodes(i);
    end    
end


% Calculating the dynamic drag force
qq = zeros([1,length(nodes),size(Y_speed,1)]);
Y_speed_temp = zeros([size(Y_speed,1),length(nodes)]);
Y_speed_temp(:,1:nodes_arch5_sum,:) = Y_speed(:,1:nodes_arch5_sum);
Y_speed_temp(:,nodes_arch5_sum+1:2:end) = Y_speed(:,nodes_arch5_sum+1:end);
Y_speed_temp(:,nodes_arch5_sum+2:2:end) = Y_speed(:,nodes_arch5_sum+1:end);
Y_speed = Y_speed_temp;
for i = 1:length(nodes)
    if i <= nodes_arch1
        qq(1,i,:) = 0.5*rho*Cd_bue*4.2*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
    elseif i <= nodes_arch2_sum
        qq(1,i,:) = 0.5*rho*Cd_bue*3.4*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
    elseif i <= nodes_arch3_sum
        qq(1,i,:) = 0.5*rho*Cd_bue*3.167*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
    elseif i <= nodes_arch4_sum
        qq(1,i,:) = 0.5*rho*Cd_bue*2.934*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
   elseif i <= nodes_arch5_sum
        qq(1,i,:) = 0.5*rho*Cd_bue*2.7*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
    else
        qq(1,i,:) = 0.5*rho*Cd_bru*27.6*Y_speed(:,i)*mean_speed(i)*length_nodes(i);
    end
end

Folder = 'C:\Users\Jorgen\Dropbox\Masteroppgave\Matlab\Simulations\0.25\files_full_in_2points';

Generate_Input_file_Load_and_Nodes(t_scale',qq,qq_stat,name,Folder,nodes);